==> StringProgressBar-1.0.0.tar.gz: StringProgressBar-1.0.0/README.md <==
<p align="center">
 <a><img width=220px height=200px src="logo.png" alt="Project logo"></a>
</p>

<h3 align="center">StringProgressBar</h3>

<div align="center">

[![GitHub Issues](https://img.shields.io/github/issues/MrJacob12/TextProgressBar.svg)](https://github.com/MrJacob12/TextProgressBar/issues)
[![License](https://img.shields.io/github/license/MrJacob12/TextProgressBar.svg)](/LICENSE)

</div>

## 📝 Table of Contents
<!-- -  -->
<!-- - [Deployment](#deployment) -->
<!-- - [Usage](#usage) -->

- [About](#about)
- [Getting Started](#getting_started)
- [Built Using](#built_using)
- [Authors](#authors)

## 🧐 About <a name = "about"></a>
Simple string progress bar made for discord bots. Its usable everywhere.

## 🏁 Getting Started <a name = "getting_started"></a>
<!-- 
These instructions will get you a copy of the project up and running on your local machine for development and testing purposes. -->

<!-- 
### Prerequisites <a name = "prerequisites"></a>

* [Python](https://www.python.org)
* [Node.js](https://nodejs.org/en/) -->


### Installing

A step by step series of examples that tell you how to get a development env running.

```bash
pip install StringProgressBar
```


<!-- End with an example of getting some data out of the system or using it for a little demo. -->

<!-- ## 🔧 Running the tests <a name = "tests"></a>

Explain how to run the automated tests for this system.

### Break down into end to end tests

Explain what these tests test and why

```
Give an example
```

### And coding style tests

Explain what these tests test and why

```
Give an example
``` -->

## 🎈 Usage <a name="usage"></a>


<!-- 
## 🚀 Deployment <a name = "deployment"></a> 

Add additional notes about how to deploy this on a live system. -->

## ⛏️ Built Using <a name = "built_using"></a>
* [Python](https://www.python.org)


## ✍️ Authors <a name = "authors"></a>

- [@MrJacob12](https://github.com/mrjacob12)

<!-- ## 🎉 Acknowledgements <a name = "acknowledgement"></a>

- Hat tip to anyone whose code was used
- Inspiration
- References -->

==> StringProgressBar-1.0.1.tar.gz: StringProgressBar-1.0.1/README.md <==
<p align="center">
 <a><img width=220px height=200px src="https://raw.githubusercontent.com/MrJacob12/StringProgressBar/master/logo.png" alt="Project logo"></a>
</p>

<h3 align="center">StringProgressBar</h3>

<div align="center">

[![GitHub Issues](https://img.shields.io/github/issues/MrJacob12/StringProgressBar.svg)](https://github.com/MrJacob12/StringProgressBar/issues)
[![License](https://img.shields.io/github/license/MrJacob12/StringProgressBar.svg)](/LICENSE)

</div>

## 📝 Table of Contents
<!-- -  -->
<!-- - [Deployment](#deployment) -->
<!-- - [Usage](#usage) -->

- [About](#about)
- [Getting Started](#getting_started)
- [Built Using](#built_using)
- [Authors](#authors)

## 🧐 About <a name = "about"></a>
Simple string progress bar made for discord bots. Its usable everywhere.

## 🏁 Getting Started <a name = "getting_started"></a>
<!-- 
These instructions will get you a copy of the project up and running on your local machine for development and testing purposes. -->

<!-- 
### Prerequisites <a name = "prerequisites"></a>

* [Python](https://www.python.org)
* [Node.js](https://nodejs.org/en/) -->


### Installing

A step by step series of examples that tell you how to get a development env running.

```bash
pip install StringProgressBar
```


<!-- End with an example of getting some data out of the system or using it for a little demo. -->

<!-- ## 🔧 Running the tests <a name = "tests"></a>

Explain how to run the automated tests for this system.

### Break down into end to end tests

Explain what these tests test and why

```
Give an example
```

### And coding style tests

Explain what these tests test and why

```
Give an example
``` -->

## 🎈 Usage <a name="usage"></a>
```python
await channel.send(progressBar.createBoxDiscord(200, 365, 20))
```
<a><img src="https://raw.githubusercontent.com/MrJacob12/StringProgressBar/master/img/s1.PNG" alt="Project logo"></a>

<!-- 
## 🚀 Deployment <a name = "deployment"></a> 

Add additional notes about how to deploy this on a live system. -->

## ⛏️ Built Using <a name = "built_using"></a>
* [Python](https://www.python.org)


## ✍️ Authors <a name = "authors"></a>

- [@MrJacob12](https://github.com/mrjacob12)

<!-- ## 🎉 Acknowledgements <a name = "acknowledgement"></a>

- Hat tip to anyone whose code was used
- Inspiration
- References -->
